###--- >>> `predict.ssanova' <<<----- Predicting from Smoothing Spline ANOVA Fits

##___ Examples ___:

## Fit a model with thin-plate marginals, where geog is 2-D
data(lake.acid)
fit <- ssanova(ph~log(cal)*geog,"tp",lake.acid)

## Obtain estimates and standard errors on a grid
new <- data.frame(cal=1,geog=I(matrix(0,1,2)))
new <- model.frame(~log(cal)+geog,new)
predict(fit,new,se=TRUE)

## Evaluate the geog main effect
predict(fit,new,se=TRUE,inc="geog")

## Evaluate the sum of the geog main effect and the interaction
predict(fit,new,se=TRUE,inc=c("geog","log(cal):geog"))

## Evaluate the geog main effect on a grid
grid <- seq(-.04,.04,len=21)
new <- model.frame(~geog,list(geog=cbind(rep(grid,21),rep(grid,rep(21,21)))))
est <- predict(fit,new,se=TRUE,inc="geog")

## Plot the fit and standard error
par(pty="s")
contour(grid,grid,matrix(est$fit,21,21),col=1)
contour(grid,grid,matrix(est$se,21,21),add=TRUE,col=2)

## Keywords: 'ssanova', 'models', 'regression', 'smoothing', 'spline'.


